# *svcs*: A Flexible Service Locator

Release **{sub-ref}`release`**  ([What's new?](changelog))

::: {admonition} ☠️ Not ready yet! ☠️
:class: danger

This project is only public to [gather feedback](https://github.com/hynek/svcs/discussions), and everything can and will change until the project is proclaimed stable.

The code has 100% test and type coverage, and the shipped *Flask* and *Pyramid* integrations have been in production for years, but the API details can still change.
:::

```{include} ../README.md
:start-after: "<!-- begin index -->"
:end-before: "<!-- end index -->"
```

Read on in *{doc}`why`*, if you find that intriguing!


## User's Guide

```{toctree}
:maxdepth: 2

why
core-concepts
flask
pyramid
custom
typing-caveats
glossary
security
```


## Project Links

```{include} ../README.md
:start-after: "## Project Links"
```


```{toctree}
:hidden: true

changelog
```
